@@ -1,3 +1,10 @@
+#!/usr/bin/python3
+# -*- coding: utf-8 -*-
+#
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at https://mozilla.org/MPL/2.0/.
+
 from naruno.apps.remote_app import Integration
 
 import time
@@ -6,11 +13,12 @@ import pickle
 import contextlib
 
 class aps:
+    command_line = False
     def __init__(self, password, timeout=180, cache_time=120, trusted_users=[], port=8000):
         self.trusted_users = trusted_users
         self.integration = Integration("APS", password=password, port=port)
-        self.timeout = timeout
-        self.cache_time = cache_time
+        self.timeout = timeout + self.integration.wait_amount
+        self.cache_time = cache_time + self.integration.wait_amount
         self.last_ping_time = 0
 
         self.load_cache()
@@ -33,6 +41,8 @@ class aps:
     
     def ping(self, user):
         if time.time() - self.last_ping_time < self.cache_time:
+            if aps.command_line:
+                self.close()            
             return True
 
         self.integration.send("message", "hi", user)
@@ -47,6 +57,8 @@ class aps:
                         if time.time() - each["transaction_time"] < self.timeout:
                             self.last_ping_time = time.time()
                             self.save_cache()
+                            if aps.command_line:
+                                self.close()
                             return True
             time.sleep(5)
 
@@ -68,4 +80,5 @@ class aps:
         self.integration.close()
 
 def main():
+    aps.command_line = True
     fire.Fire(aps)
\ No newline at end of file
